[xoops-cvslog 2933] CVS update: xoops2jp/html/class/mail

Back to archive index

onokazu onoka****@users*****
2006年 5月 1日 (月) 11:37:25 JST


Index: xoops2jp/html/class/mail/xoopsmultimailer.php
diff -u xoops2jp/html/class/mail/xoopsmultimailer.php:1.2 xoops2jp/html/class/mail/xoopsmultimailer.php:1.3
--- xoops2jp/html/class/mail/xoopsmultimailer.php:1.2	Fri Mar 18 21:51:55 2005
+++ xoops2jp/html/class/mail/xoopsmultimailer.php	Mon May  1 11:37:24 2006
@@ -1,5 +1,5 @@
 <?php
-// $Id: xoopsmultimailer.php,v 1.2 2005/03/18 12:51:55 onokazu Exp $
+// $Id: xoopsmultimailer.php,v 1.3 2006/05/01 02:37:24 onokazu Exp $
 //  ------------------------------------------------------------------------ //
 //                XOOPS - PHP Content Management System                      //
 //                    Copyright (c) 2000 XOOPS.org                           //
@@ -37,7 +37,7 @@
  * @author		Jochen Büînagel	<jb****@buenn*****>
  * @copyright	copyright (c) 2000-2003 The XOOPS Project (http://www.xoops.org)
  *
- * @version		$Revision: 1.2 $ - $Date: 2005/03/18 12:51:55 $
+ * @version		$Revision: 1.3 $ - $Date: 2006/05/01 02:37:24 $
  */
 
 /**
@@ -61,9 +61,9 @@
  *
  * @author		Jochen Buennagel	<job****@buenn*****>
  * @copyright	(c) 2000-2003 The Xoops Project - www.xoops.org
- * @version		$Revision: 1.2 $ - changed by $Author: onokazu $ on $Date: 2005/03/18 12:51:55 $
+ * @version		$Revision: 1.3 $ - changed by $Author: onokazu $ on $Date: 2006/05/01 02:37:24 $
  */
-class XoopsMultiMailer extends phpmailer {
+class XoopsMultiMailer extends PHPMailer {
 
 	/**
 	 * "from" address
@@ -157,7 +157,7 @@
 		if ($this->From == '') {
 		    $this->From = $xoopsConfig['adminmail'];
 		}
-		
+		// $this->Sender = $xoopsConfig['adminmail']; //TODO: This line is added in OTX by Marijuana. We must verify.
 		if ($xoopsMailerConfig["mailmethod"] == "smtpauth") {
 		    $this->Mailer = "smtp";
 			$this->SMTPAuth = TRUE;
@@ -173,11 +173,14 @@
 	}
 
 	/**
      * Formats an address correctly. This overrides the default addr_format method which does not seem to encode $FromName correctly
      * @access private
      * @return string
      */
-    function addr_format($addr) {
+     //TODO: We must verify,whether we should prepare this method even now.(phpmailer is upgraded from 1.65 to 1.73)
+    function AddrFormat($addr) {
         if(empty($addr[1]))
             $formatted = $addr[0];
         else
@@ -173,11 +173,14 @@
 
 	/**
-     * Formats an address correctly. This overrides the default addr_format method which does not seem to encode $FromName correctly
+     * Formats an address correctly. This overrides the default AddrFormat method
+     * which does not seem to encode $FromName correctly
+     * This method name is renamed from "addr_format", because method name in parent class is renamed.
      * @access private
      * @return string


xoops-cvslog メーリングリストの案内
Back to archive index